/*These are the Stata commands used to generate Tables 1, 2, 3 and 4 in the article, 
"Do Countries with Greater Credit Constraints Receive More Foreiagn Aid?" 

by Subhayu Bandyopadhyay, Sajal Lahiri and Javed Younas for the
Nov/Dec 2012, Vol. 94(6) issue of the Federal Reserve Bank of St. Louis Review.

See the excel data file for the variables and their descriptions. 

*/

** SET WORKING DIRECTORY **
* cd 

insheet using foreignaidloans.csv, clear
set matsize 800
tsset iid year, yearly
gen lnpop=ln(pop)
gen lngdppc=ln(gdppc)
gen lninfm=ln(infm)
gen lntrade=ln(trade)
gen popm=pop/1000000

/*political right and civil liberties*/
gen prclt=prt+clt
gen lnprclt=ln(prclt)

/*converting aid into real aid per capita*/
gen tndpc=tnd/popm
gen bndpc=bnd/popm
gen tndpcr=tndpc/cpi
gen bndpcr=bndpc/cpi

/*converting loans (in millions exchange rate adjusted) into loans per capita*/
gen loanspc=loans/popm

/*log transformation of variables with negative values such  
that after this transformation lowest value equals zero*/

sum tndpcr bndpcr loanspc gdppc infm pop trade inflation prclt vacc
gen lntndpcr=ln(tndpcr+140.647)
gen lnbndpcr=ln(bndpcr+158.6586)
gen lnloanspc=ln(loanspc+10667.33)
gen lnvacc=ln(vacc+3.151)
gen lninflation=ln(inflation+24.490)

/*creating quadratic inflation term*/
gen lninflationsq=lninflation*lninflation

/*Summary Statistics - Table 1*/
sum lntndpcr lnbndpcr lnloanspc lngdppc lninfm lnpop lntrade lninflation lnprclt lnvacc

/*mean, median and percentile levels of aid and loans variables*/
sum lntndpcr lnbndpcr lnloanspc, d

/*Regression results - Table 2*/
xtabond2 lntndpcr l.lntndpcr (lnloanspc lngdppc lnpop lnprclt lntrade lninflation lninflationsq) y2-y12, gmm(lnloanspc lngdppc lnpop lnprclt lntrade lninflation lninflationsq, lag(4 4)) twostep small
xtabond2 lntndpcr l.lntndpcr (lnloanspc lngdppc lnpop lnvacc lntrade lninflation lninflationsq) y2-y12, gmm(lnloanspc lngdppc lnpop lnvacc lntrade lninflation lninflationsq, lag(4 4)) twostep small
xtabond2 lntndpcr l.lntndpcr (lnloanspc lninfm lnpop lnprclt lntrade lninflation lninflationsq) y2-y12, gmm(lnloanspc lninfm lnpop lnprclt lntrade lninflation lninflationsq, lag(4 4)) twostep small
xtabond2 lntndpcr l.lntndpcr (lnloanspc lninfm lnpop lnvacc lntrade lninflation lninflationsq) y2-y12, gmm(lnloanspc lninfm lnpop lnvacc lntrade lninflation lninflationsq, lag(4 4)) twostep small

/*Regression results - Table 3*/
xtabond2 lnbndpcr l.lnbndpcr (lnloanspc lngdppc lnpop lnprclt lntrade lninflation lninflationsq) y2-y12, gmm(lnloanspc lngdppc lnpop lnprclt lntrade lninflation lninflationsq, lag(4 4)) twostep small
xtabond2 lnbndpcr l.lnbndpcr (lnloanspc lngdppc lnpop lnvacc lntrade lninflation lninflationsq) y2-y12, gmm(lnloanspc lngdppc lnpop lnvacc lntrade lninflation lninflationsq, lag(4 4)) twostep small
xtabond2 lnbndpcr l.lnbndpcr (lnloanspc lninfm lnpop lnprclt lntrade lninflation lninflationsq) y2-y12, gmm(lnloanspc lninfm lnpop lnprclt lntrade lninflation lninflationsq, lag(4 4)) twostep small
xtabond2 lnbndpcr l.lnbndpcr (lnloanspc lninfm lnpop lnvacc lntrade lninflation lninflationsq) y2-y12, gmm(lnloanspc lninfm lnpop lnvacc lntrade lninflation lninflationsq, lag(4 4)) twostep small

/*Regressions results by excluding OPEC countries - Table 4 columns 1 & 2*/
drop if iid==6
drop if iid==9
drop if iid==102
drop if iid==159
drop if iid==189
drop if iid==243
drop if iid==351

xtabond2 lntndpcr l.lntndpcr (lnloanspc lngdppc lnpop lnprclt lntrade lninflation lninflationsq) y2-y12, gmm(lnloanspc lngdppc lnpop lnprclt lntrade lninflation lninflationsq, lag(6 6)) twostep small
xtabond2 lnbndpcr l.lnbndpcr (lnloanspc lngdppc lnpop lnprclt lntrade lninflation lninflationsq) y2-y12, gmm(lnloanspc lngdppc lnpop lnprclt lntrade lninflation lninflationsq, lag(6 6)) twostep small

/*Regressions results by also excluding transition economies along with OPEC countries- Table 4 columns 3 & 4*/
drop if iid==3
drop if iid==15
drop if iid==51
drop if iid==69
drop if iid==90
drop if iid==126
drop if iid==168
drop if iid==177
drop if iid==180
drop if iid==219
drop if iid==285
drop if iid==312
drop if iid==336
drop if iid==345
drop if iid==354

xtabond2 lntndpcr l.lntndpcr (lnloanspc lngdppc lnpop lnprclt lntrade lninflation lninflationsq) y2-y12, gmm(lnloanspc lngdppc lnpop lnprclt lntrade lninflation lninflationsq, lag(6 6)) twostep small
xtabond2 lnbndpcr l.lnbndpcr (lnloanspc lngdppc lnpop lnprclt lntrade lninflation lninflationsq) y2-y12, gmm(lnloanspc lngdppc lnpop lnprclt lntrade lninflation lninflationsq, lag(6 6)) twostep small
